@@ -38,6 +38,11 @@ def get_plugin_path(plugin_name, type='php', all_types=False):
                 return _generate_plugin_path(plugin_name, config['php_next']['paths'])
             else:
                 return False
+        elif type == 'node_next':
+            if _generate_plugin_path(plugin_name, config['node_next']['paths']):
+                return _generate_plugin_path(plugin_name, config['node_next']['paths'])
+            else:
+                return False
         else:
             Log.error("Invalid params for type.")
             return False
@@ -47,7 +52,8 @@ def get_plugin_path(plugin_name, type='php', all_types=False):
             config['php']['paths'] if 'php' in config else None,
             config['node']['paths'] if 'node' in config else None,
             config['python']['paths'] if 'python' in config else None,
-            config['php_next']['paths'] if 'php_next' in config else None
+            config['php_next']['paths'] if 'php_next' in config else None,
+            config['node_next']['paths'] if 'node_next' in config else None
         ]
 
         for base_paths in base_paths_list:
@@ -186,4 +192,4 @@ def _generate_plugin_path(plugin_name, paths):
         plugin_path = path.expanduser(plugin_path)
         if(path.exists(plugin_path)):
             return plugin_path
-    return False
\ No newline at end of file
+    return False
